summaryrefslogtreecommitdiff
path: root/libmu_scm/mu_scm.c
diff options
context:
space:
mode:
Diffstat (limited to 'libmu_scm/mu_scm.c')
-rw-r--r--libmu_scm/mu_scm.c12
1 files changed, 8 insertions, 4 deletions
diff --git a/libmu_scm/mu_scm.c b/libmu_scm/mu_scm.c
index a5767a0de..8f201289c 100644
--- a/libmu_scm/mu_scm.c
+++ b/libmu_scm/mu_scm.c
@@ -47,10 +47,11 @@ mu_set_variable (const char *name, SCM value)
scm_c_define (name, value);
}
-SCM _mu_scm_package; /* STRING: PACKAGE */
-SCM _mu_scm_version; /* STRING: VERSION */
-SCM _mu_scm_mailer; /* STRING: Default mailer path. */
-SCM _mu_scm_debug; /* NUM: Default debug level. */
+SCM _mu_scm_package_string; /* STRING: PACKAGE_STRING */
+SCM _mu_scm_package; /* STRING: PACKAGE */
+SCM _mu_scm_version; /* STRING: VERSION */
+SCM _mu_scm_mailer; /* STRING: Default mailer path. */
+SCM _mu_scm_debug; /* NUM: Default debug level. */
struct format_record {
char *name;
@@ -179,6 +180,9 @@ mu_scm_init ()
_mu_scm_version = scm_makfrom0str (VERSION);
mu_set_variable ("mu-version", _mu_scm_version);
+ _mu_scm_package_string = scm_makfrom0str (PACKAGE_STRING);
+ mu_set_variable ("mu-package-string", _mu_scm_package_string);
+
/* Create MU- attribute names */
for (i = 0; attr_kw[i].name; i++)
scm_c_define(attr_kw[i].name, SCM_MAKINUM(attr_kw[i].value));

Return to:

Send suggestions and report system problems to the System administrator.